#
# spec file for package xmlgraphics-commons
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2000-2008, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xmlgraphics-commons
Version:        2.3
Release:        1.68
Summary:        XML Graphics Commons
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            http://xmlgraphics.apache.org/
Source0:        http://archive.apache.org/dist/xmlgraphics/commons/source/xmlgraphics-commons-%{version}-src.tar.gz
Patch0:         xmlgraphics-commons-build_xml.patch
Patch1:         xmlgraphics-commons-jdk10.patch
BuildRequires:  ant >= 1.6.5
BuildRequires:  commons-io >= 1.1
BuildRequires:  commons-logging
BuildRequires:  fdupes
BuildRequires:  javapackages-local
Requires:       mvn(commons-io:commons-io) >= 1.1
Requires:       mvn(commons-logging:commons-logging)
BuildArch:      noarch

%description
Apache XML Graphics Commons is a library that consists of
several reusable components used by Apache Batik and
Apache FOP. Many of these components can easily be used
separately outside the domains of SVG and XSL-FO. You will
find components such as a PDF library, an RTF library,
Graphics2D implementations that let you generate PDF &
PostScript files, and much more.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
Javadoc for package %{name}.

%prep
%setup -q %{name}-%{version}
%patch0
%patch1 -p1
find . -name "*.jar" | xargs rm

%build
export CLASSPATH=
build-jar-repository -s lib commons-io commons-logging
ant -Djavac.source=1.6 -Djavac.target=1.6 package javadocs

%install
# jar
install -Dpm 644 build/%{name}-%{version}.jar \
  %{buildroot}%{_javadir}/%{name}.jar
# pom
install -Dpm 644 pom.xml %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar

mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr build/javadocs/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE
%doc README

%files javadoc
%license LICENSE NOTICE
%{_javadocdir}/%{name}

%changelog
* Sat Jan 19 2019 fstrba@suse.com
- Modified patch:
  * xmlgraphics-commons-build_xml.patch
    + Add Bundle-SymbolicName and Bundle-Version attributes to
    generate the right OSGi provides
- Sanitize spec file and remove unused requires
* Tue Aug 28 2018 tchvatal@suse.com
- Do not run target  maven_artifacts as it just copies file from a->b
  and fails with newer ant
* Tue Aug 28 2018 tchvatal@suse.com
- Update to version 2.3:
  * no changelog available
* Fri Dec 22 2017 fstrba@suse.com
- Added patch:
  * xmlgraphics-commons-jdk10.patch
    + Fix building with jdk10
* Fri Sep 29 2017 fstrba@suse.com
- Don't condition the maven defines on release version, but on
  _maven_repository being defined
* Tue Sep 19 2017 fstrba@suse.com
- Fix build with jdk9: specify java source and target level 1.6
* Fri May 19 2017 vsistek@suse.com
- Add BuildRequires: javapackages-local (for maven conversions)
* Mon Mar 20 2017 sknorr@suse.com
- Needed as a dependency for FOP 2.1 (FATE#322405)
- Switch between maven-metadata/maven-fragments as appropriate
  for SLE/openSUSE
* Mon Mar  6 2017 sknorr@suse.com
- Switch between maven-metadata/maven-fragments as appropriate
  for SLE/openSUSE (FATE#322405)
* Thu Mar  3 2016 fvogt@suse.com
- Update to version 2.1
  - No changelog available
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Fri Dec  5 2014 p.drouand@gmail.com
- Update to version 2.0
  + No changelog available
- Do not use gpg_verify anymore; OBS handles source verification
- Remove dependency on java-devel
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Fri Sep  6 2013 mvyskocil@suse.com
- format spec file
- use new add_maven_depmap macro
- build require apache-commons packages
- add gpg verification
* Wed Jan 23 2013 mvyskocil@suse.com
- fix javadoc installation
* Wed Oct 31 2012 mvyskocil@suse.com
- remove the symlink madness - jar and javadoc are not versioned anymore
* Wed Oct 24 2012 mvyskocil@suse.com
- update to 1.5
  * bug fix release
  * improved code practices
  * improved coverage of CCITTFax Group 3 image formats
  * removed com.sun classes usage
  * see http://xmlgraphics.apache.org/commons/changes.html#version_1.5
  * drop upstreamed java7 patch
* Mon Jun 18 2012 mvyskocil@suse.cz
- fix jdk7 build (Fedora patch)
* Wed Nov  3 2010 mvyskocil@suse.cz
- Initial packaging for SUSE (xmlgraphics-commons-1.3.1-2.jpp5.src.rpm)
